/**
  * ******************************************************
  *                                                       *
  *   Copyright (C) Microsoft. All rights reserved.       *
  *                                                       *
  *******************************************************
  */
"use strict";
const nconf = require("nconf");
const path = require("path");
const HostSpecifics = require("./host-specifics");
const util = require("vcremote-utils");
const server = require("./server");
var resources = util.ResourcesManager;
function cli() {
    console.info("vcremote");
    console.info("Copyright (C) 2014 Microsoft Corporation. All rights reserved.");
    console.info(require("../package").version);
    console.info("");
    // Configuration preference: command line, then anything in a config file if specified by the --config arg, then some defaults for options not yet set
    nconf.argv();
    if (nconf.get("v") || nconf.get("version")) {
        process.exit(0);
    }
    if (nconf.get("config")) {
        nconf.file({ file: nconf.get("config") });
    }
    ;
    var defaults = {
        port: 3030,
        maxBuildsInQueue: 100,
        maxBuildsToKeep: 200,
        deleteBuildsOnShutdown: true,
        secure: true,
        allowsEmulate: true
    };
    defaults = HostSpecifics.hostSpecifics.defaults(defaults);
    nconf.defaults(defaults);
    // Initialize localization resources
    resources.init(nconf.get("lang"), path.join(__dirname, "..", "localization/app/localization/i18n"));
    if (nconf.get("help") || nconf.get("h") || nconf.get("?") || !nconf.get("serverDir")) {
        HostSpecifics.hostSpecifics.printUsage(nconf.get("lang"));
        process.exit(0);
    }
    var commands = nconf.get("_");
    var command = commands && commands.length > 0 ? commands[0] : "start";
    var task = tasks[command];
    if (task) {
        new Promise(function (resolve, reject) { resolve(task.execute()); });
    }
    else {
        console.info(resources.getStringForLanguage(nconf.get("lang"), "UnknownCommand"), command);
        HostSpecifics.hostSpecifics.printUsage(nconf.get("lang"));
        process.exit(0);
    }
}
var tasks;
tasks = {
    start: {
        execute: function () {
            return HostSpecifics.hostSpecifics.initialize()
                .then(function () { server.start(nconf); });
        }
    },
    resetServerCert: {
        execute: function () {
            return server.resetServerCert(nconf);
        }
    }
};
module.exports = cli;
