/**
  * ******************************************************
  *                                                       *
  *   Copyright (C) Microsoft. All rights reserved.       *
  *                                                       *
  *******************************************************
  */
"use strict";
const path = require("path");
const utils = require("vcremote-utils");
var resources = utils.ResourcesManager;
class Win32Specifics {
    defaults(base) {
        var windefaults = {
            serverDir: path.join(process.env.APPDATA, require("../../package").name),
            allowsEmulate: false,
            lang: "en",
            suppressVisualStudioMessage: false,
        };
        Object.keys(windefaults).forEach(function (key) {
            if (!(key in base)) {
                base[key] = windefaults[key];
            }
        });
        return base;
    }
    initialize() {
        return new Promise(function (resolve, reject) { resolve({}); });
    }
    printUsage(language) {
        console.info(resources.getStringForLanguage(language, "UsageInformation"));
    }
    resetServerCert(conf) {
        return new Promise(function (resolve, reject) { resolve({}); });
    }
    initializeServerCerts(conf) {
        return new Promise(function (resolve, reject) {
            resolve({
                newCerts: false,
                getKey: function () { throw new Error("Not Implemented"); },
                getCert: function () { throw new Error("Not Implemented"); },
            });
        });
    }
    getServerCerts(conf) {
        return {
            newCerts: false,
            getKey: function () { throw new Error("Not Implemented"); },
            getCert: function () { throw new Error("Not Implemented"); },
        };
    }
    removeAllCertsSync(conf) {
        return;
    }
}
var win32Specifics = new Win32Specifics();
module.exports = win32Specifics;
